pub enum OutputEvent {
Clicked(WidgetInfo),
DoubleClicked(WidgetInfo),
TripleClicked(WidgetInfo),
FocusGained(WidgetInfo),
TextSelectionChanged(WidgetInfo),
ValueChanged(WidgetInfo),
}Expand description
Things that happened during this frame that the integration may be interested in.
In particular, these events may be useful for accessibility, i.e. for screen readers.
Variants
Clicked(WidgetInfo)
A widget was clicked.
DoubleClicked(WidgetInfo)
A widget was double-clicked.
TripleClicked(WidgetInfo)
A widget was triple-clicked.
FocusGained(WidgetInfo)
A widget gained keyboard focus (by tab key).
TextSelectionChanged(WidgetInfo)
Text selection was updated.
ValueChanged(WidgetInfo)
A widget’s value changed.
Implementations
Sourceimpl OutputEvent
impl OutputEvent
pub fn widget_info(&self) -> &WidgetInfo