pub struct Interaction {
pub resize_grab_radius_side: f32,
pub resize_grab_radius_corner: f32,
pub show_tooltips_only_when_still: bool,
pub tooltip_delay: f64,
}Expand description
How and when interaction happens.
Fields
resize_grab_radius_side: f32Mouse must be this close to the side of a window to resize
resize_grab_radius_corner: f32Mouse must be this close to the corner of a window to resize
show_tooltips_only_when_still: boolIf false, tooltips will show up anytime you hover anything, even is mouse is still moving
tooltip_delay: f64Delay in seconds before showing tooltips after the mouse stops moving
Implementations